@@ -1,14 +1,13 @@
 """Assign coordinates to the nodes of a graph.
 """
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
 import numba as nb
 import numpy as np
 import param
 import scipy.sparse
 
-
 class LayoutAlgorithm(param.ParameterizedFunction):
     """
     Baseclass for all graph layout algorithms.
@@ -66,10 +65,10 @@ class random_layout(LayoutAlgorithm):
     def __call__(self, nodes, edges=None, **params):
         p = param.ParamOverrides(self, params)
 
-        np.random.seed(p.seed)
+        rng = np.random.default_rng(p.seed)
 
         df = nodes.copy()
-        points = np.asarray(np.random.random((len(df), 2)))
+        points = np.asarray(rng.random((len(df), 2)))
 
         df[p.x] = points[:, 0]
         df[p.y] = points[:, 1]
@@ -93,7 +92,7 @@ class circular_layout(LayoutAlgorithm):
     def __call__(self, nodes, edges=None, **params):
         p = param.ParamOverrides(self, params)
 
-        np.random.seed(p.seed)
+        rng = np.random.default_rng(p.seed)
 
         r = 0.5  # radius
         x0, y0 = 0.5, 0.5  # center of unit circle
@@ -104,7 +103,7 @@ class circular_layout(LayoutAlgorithm):
         if p.uniform:
             thetas = np.arange(circumference, step=circumference/len(df))
         else:
-            thetas = np.asarray(np.random.random((len(df),))) * circumference
+            thetas = np.asarray(rng.random((len(df),))) * circumference
 
         df[p.x] = x0 + r * np.cos(thetas)
         df[p.y] = y0 + r * np.sin(thetas)
@@ -112,11 +111,14 @@ class circular_layout(LayoutAlgorithm):
         return df
 
 
-def _extract_points_from_nodes(nodes, params, dtype=None):
+def _extract_points_from_nodes(nodes, params, dtype=None, rng=None):
+    if rng is None:
+        rng = np.random.default_rng()
+
     if params.x in nodes.columns and params.y in nodes.columns:
         points = np.asarray(nodes[[params.x, params.y]])
     else:
-        points = np.asarray(np.random.random((len(nodes), params.dim)), dtype=dtype)
+        points = np.asarray(rng.random((len(nodes), params.dim)), dtype=dtype)
     return points
 
 
@@ -170,14 +172,25 @@ def _merge_points_with_nodes(nodes, points, params):
     n[params.y] = points[:, 1]
     return n
 
-
-@nb.jit(nogil=True)
 def cooling(matrix, points, temperature, params):
-    dt = temperature / float(params.iterations + 1)
-    displacement = np.zeros((params.dim, len(points)))
-    for iteration in range(params.iterations):
+    matrix = matrix.toarray()
+    c_params = {
+        'iterations': params.iterations,
+        'dim': params.dim,
+        'k': params.k,
+        'nohubs': params.nohubs,
+        'linlog': params.linlog
+    }
+    _cooling(matrix, points, temperature, **c_params)
+
+
+@nb.jit(nopython=True, nogil=True, parallel=True)
+def _cooling(matrix, points, temperature, iterations, dim, k, nohubs, linlog):
+    dt = temperature / float(iterations + 1)
+    displacement = np.zeros((dim, len(points)))
+    for iteration in range(iterations):
         displacement *= 0
-        for i in range(matrix.shape[0]):
+        for i in nb.prange(matrix.shape[0]):
             # difference between this row's node position and all others
             delta = (points[i] - points).T
 
@@ -188,16 +201,16 @@ def cooling(matrix, points, temperature, params):
             distance = np.where(distance < 0.01, 0.01, distance)
 
             # the adjacency matrix row
-            ai = matrix[i].toarray()
+            ai = matrix[i]
 
             # displacement "force"
-            dist = params.k * params.k / distance ** 2
+            dist = k * k / distance ** 2
 
-            if params.nohubs:
+            if nohubs:
                 dist = dist / float(ai.sum(axis=1) + 1)
-            if params.linlog:
+            if linlog:
                 dist = np.log(dist + 1)
-            displacement[:, i] += (delta * (dist - ai * distance / params.k)).sum(axis=1)
+            displacement[:, i] += (delta * (dist - ai * distance / k)).sum(axis=1)
 
         # update points
         length = np.sqrt((displacement ** 2).sum(axis=0))
@@ -245,10 +258,10 @@ class forceatlas2_layout(LayoutAlgorithm):
     def __call__(self, nodes, edges, **params):
         p = param.ParamOverrides(self, params)
 
-        np.random.seed(p.seed)
+        rng = np.random.default_rng(p.seed)
 
         # Convert graph into sparse adjacency matrix and array of points
-        points = _extract_points_from_nodes(nodes, p, dtype='f')
+        points = _extract_points_from_nodes(nodes, p, dtype='f', rng=rng)
         matrix = _convert_graph_to_sparse_matrix(nodes, edges, p, dtype='f')
 
         if p.k is None:
