@@ -1,5 +1,5 @@
+from __future__ import annotations
 import pytest
-skimage = pytest.importorskip("skimage")
 
 import numpy as np
 import pandas as pd
@@ -7,6 +7,8 @@ import pandas as pd
 from datashader.bundling import directly_connect_edges, hammer_bundle
 from datashader.layout import circular_layout, forceatlas2_layout, random_layout
 
+skimage = pytest.importorskip("skimage")
+
 
 @pytest.fixture
 def nodes():
@@ -24,7 +26,7 @@ def edges():
     # Four edges originating from the center node and connected to each
     # corner
     edges_df = pd.DataFrame({'id': np.arange(4),
-                             'source': np.zeros(4, dtype=np.int),
+                             'source': np.zeros(4, dtype=int),
                              'target': np.arange(1, 5)})
     edges_df.set_index('id')
     return edges_df
@@ -35,7 +37,7 @@ def weighted_edges():
     # Four weighted edges originating from the center node and connected
     # to each corner
     edges_df = pd.DataFrame({'id': np.arange(4),
-                             'source': np.zeros(4, dtype=np.int),
+                             'source': np.zeros(4, dtype=int),
                              'target': np.arange(1, 5),
                              'weight': np.ones(4)})
     edges_df.set_index('id')
